@@ -8,9 +8,14 @@ references as human-readable strings.
 
 from __future__ import annotations
 
-__version__ = "0.14.0"
+__version__ = "0.15.1"
 
+from .bible import add_bible
+from .bible import get_bible
 from .bible.bible import Bible
+from .bible.errors import VersionMissingBookError
+from .bible.errors import VersionMissingChapterError
+from .bible.errors import VersionMissingVerseError
 from .book_groups import BOOK_GROUPS
 from .book_groups import BookGroup
 from .books import Book
@@ -20,17 +25,13 @@ from .converter import convert_verse_ids_to_references
 from .counters.book_counter import count_books
 from .counters.chapter_counter import count_chapters
 from .counters.verse_counter import count_verses
-from .errors import InvalidBibleParserError
 from .errors import InvalidBookError
 from .errors import InvalidChapterError
 from .errors import InvalidVerseError
-from .errors import MissingBookFileError
-from .errors import MissingVerseFileError
-from .errors import VersionMissingVerseError
+from .errors import MissingBiblePackageError
 from .formatter import format_scripture_references
 from .formatter import format_scripture_text
 from .formatter import format_single_reference
-from .formatter import get_book_titles
 from .formatter import get_verse_text
 from .normalized_reference import NormalizedReference
 from .parser import get_references
@@ -48,3 +49,48 @@ from .verses import get_number_of_verses
 from .verses import get_verse_id
 from .verses import get_verse_number
 from .versions import Version
+
+__all__ = [
+    "BOOK_GROUPS",
+    "Bible",
+    "Book",
+    "BookGroup",
+    "InvalidBookError",
+    "InvalidChapterError",
+    "InvalidVerseError",
+    "MissingBiblePackageError",
+    "NormalizedReference",
+    "Version",
+    "VersionMissingBookError",
+    "VersionMissingChapterError",
+    "VersionMissingVerseError",
+    "__version__",
+    "add_bible",
+    "convert_reference_to_verse_ids",
+    "convert_references_to_verse_ids",
+    "convert_verse_ids_to_references",
+    "count_books",
+    "count_chapters",
+    "count_verses",
+    "format_scripture_references",
+    "format_scripture_text",
+    "format_single_reference",
+    "get_bible",
+    "get_book_chapter_verse",
+    "get_book_number",
+    "get_chapter_number",
+    "get_number_of_chapters",
+    "get_number_of_verses",
+    "get_references",
+    "get_verse_id",
+    "get_verse_number",
+    "get_verse_text",
+    "is_valid_book",
+    "is_valid_chapter",
+    "is_valid_reference",
+    "is_valid_verse",
+    "is_valid_verse_id",
+    "normalize_reference",
+]
+# Reference the imported names so ruff/auto-fixes do not remove them as "unused".
+_ = tuple(globals().get(name) for name in __all__)
