@@ -32,10 +32,15 @@ class InvalidVerseError(Exception):
         """Initialize InvalidVerseError.
 
         :param message: optional message string
+        :type message: str | None
         :param verse_id: optional verse id
+        :type verse_id: int | None
         :param book: optional Book
+        :type book: Book | None
         :param chapter: optional chapter number
+        :type chapter: int | None
         :param verse: optional verse number
+        :type verse: int | None
         """
         self.message: str | None = message
 
@@ -48,29 +53,5 @@ class InvalidVerseError(Exception):
         super().__init__(self.message)
 
 
-class InvalidBibleParserError(Exception):
-    """Raised when the Bible parser is not valid."""
-
-
-class MissingVerseFileError(Exception):
-    """Raised when the verse file for a given version is not found."""
-
-
-class MissingBookFileError(Exception):
-    """Raised when the book file for a given version is not found."""
-
-
-class VersionMissingVerseError(Exception):
-    """Raised when the verse for a given version is missing from the version."""
-
-    def __init__(
-        self: VersionMissingVerseError,
-        version: str,
-        verse_id: int,
-    ) -> None:
-        """Initialize VersionMissingVerseError.
-
-        :param version: version string
-        :param verse_id: verse id
-        """
-        super().__init__(f"{version} is missing verse {verse_id}.")
+class MissingBiblePackageError(Exception):
+    """Raised when the Bible package for a given version is not found."""
