@@ -1,11 +1,18 @@
 from __future__ import annotations
 
 from functools import lru_cache
+from typing import TYPE_CHECKING
 
 from pythonbible.books import Book
 from pythonbible.errors import InvalidChapterError
 from pythonbible.errors import InvalidVerseError
 
+if TYPE_CHECKING:
+    from pythonbible.bible.bible import Bible
+
+
+# This is a "standard" set of maximum verse numbers by book and chapter that can be
+# overridden by specific Bible versions if necessary.
 MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
     Book.GENESIS: [
         31,
@@ -24,10 +31,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         24,
         21,
         16,
-        28,
-        34,
+        27,
+        33,
         38,
-        19,
+        18,
         34,
         24,
         20,
@@ -45,18 +52,18 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         29,
         43,
         36,
-        32,
-        27,
-        25,
-        59,
-        39,
+        30,
+        23,
+        23,
+        57,
+        38,
         34,
         34,
         28,
         34,
         31,
         22,
-        36,
+        33,
         26,
     ],
     Book.EXODUS: [
@@ -87,7 +94,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         40,
         37,
         21,
-        44,
+        43,
         46,
         38,
         18,
@@ -106,7 +113,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         16,
         17,
         35,
-        26,
+        19,
         30,
         38,
         36,
@@ -137,20 +144,20 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         49,
         31,
         27,
-        92,
+        89,
         26,
         23,
         36,
         35,
         16,
-        34,
+        33,
         45,
         41,
         50,
         13,
         32,
         22,
-        30,
+        29,
         35,
         41,
         30,
@@ -160,7 +167,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         23,
         31,
         40,
-        17,
+        16,
         54,
         42,
         56,
@@ -169,7 +176,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         13,
     ],
     Book.DEUTERONOMY: [
-        48,
+        46,
         37,
         29,
         49,
@@ -194,10 +201,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         22,
         19,
-        20,
-        27,
+        19,
+        26,
         68,
-        30,
+        29,
         20,
         30,
         52,
@@ -206,10 +213,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
     ],
     Book.JOSHUA: [
         18,
-        26,
+        24,
         17,
-        25,
-        16,
+        24,
+        15,
         27,
         26,
         35,
@@ -222,7 +229,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         63,
         10,
         18,
-        29,
+        28,
         51,
         9,
         45,
@@ -232,11 +239,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
     ],
     Book.JUDGES: [
         36,
-        29,
+        23,
         31,
         24,
-        32,
-        41,
+        31,
+        40,
         25,
         35,
         57,
@@ -253,7 +260,12 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         48,
         25,
     ],
-    Book.RUTH: [22, 23, 18, 22],
+    Book.RUTH: [
+        22,
+        23,
+        18,
+        22,
+    ],
     Book.SAMUEL_1: [
         28,
         36,
@@ -274,11 +286,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         58,
         30,
         24,
-        43,
+        42,
         15,
         23,
         29,
-        23,
+        22,
         44,
         25,
         12,
@@ -292,7 +304,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         32,
         39,
         12,
-        26,
+        25,
         23,
         29,
         18,
@@ -319,7 +331,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         28,
         34,
         18,
-        40,
+        38,
         51,
         66,
         28,
@@ -335,7 +347,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         21,
         43,
         29,
-        54,
+        53,
     ],
     Book.KINGS_2: [
         18,
@@ -348,11 +360,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         29,
         37,
         36,
-        22,
+        21,
         21,
         25,
         29,
-        39,
+        38,
         20,
         41,
         37,
@@ -376,7 +388,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         44,
         14,
         47,
-        41,
+        40,
         14,
         17,
         29,
@@ -385,7 +397,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         19,
         8,
-        31,
+        30,
         19,
         32,
         31,
@@ -399,7 +411,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         18,
         17,
-        23,
+        22,
         14,
         42,
         22,
@@ -425,18 +437,53 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         9,
         27,
         36,
-        28,
+        27,
         21,
         33,
         25,
         33,
         27,
         23,
-        1,
     ],
-    Book.EZRA: [11, 70, 13, 24, 17, 22, 28, 36, 15, 44],
-    Book.NEHEMIAH: [11, 20, 32, 23, 19, 19, 73, 18, 38, 39, 36, 47, 31],
-    Book.ESTHER: [22, 23, 15, 17, 15, 14, 10, 17, 32, 13, 12, 6, 18, 19, 19, 24],
+    Book.EZRA: [
+        11,
+        70,
+        13,
+        24,
+        17,
+        22,
+        28,
+        36,
+        15,
+        44,
+    ],
+    Book.NEHEMIAH: [
+        11,
+        20,
+        32,
+        23,
+        19,
+        19,
+        73,
+        18,
+        38,
+        39,
+        36,
+        47,
+        31,
+    ],
+    Book.ESTHER: [
+        22,
+        23,
+        15,
+        17,
+        14,
+        14,
+        10,
+        17,
+        32,
+        3,
+    ],
     Book.JOB: [
         22,
         13,
@@ -453,7 +500,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         28,
         22,
         35,
-        23,
+        22,
         16,
         21,
         29,
@@ -476,164 +523,162 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         33,
         24,
         41,
-        38,
-        28,
+        30,
+        24,
         34,
         17,
     ],
     Book.PSALMS: [
         6,
-        13,
-        9,
-        10,
-        13,
-        11,
-        18,
-        10,
-        39,
-        18,
-        32,
-        9,
-        7,
-        7,
-        10,
-        15,
-        51,
-        51,
-        15,
-        14,
-        32,
-        32,
-        10,
-        22,
-        22,
-        14,
-        14,
-        11,
-        13,
-        25,
-        25,
-        22,
-        23,
-        28,
-        29,
-        40,
-        41,
-        23,
-        18,
-        18,
-        14,
         12,
-        26,
-        27,
-        18,
-        12,
-        15,
-        21,
-        23,
-        25,
-        21,
-        11,
-        9,
-        24,
-        26,
-        14,
-        12,
-        18,
-        18,
-        14,
-        13,
-        13,
-        12,
-        14,
-        20,
-        21,
-        36,
-        37,
-        37,
-        24,
-        24,
-        28,
-        28,
-        24,
-        13,
-        21,
-        72,
-        72,
-        20,
-        20,
-        17,
-        19,
-        19,
-        14,
-        17,
-        17,
-        19,
-        53,
-        53,
-        17,
-        17,
-        16,
-        23,
-        23,
-        13,
-        13,
-        12,
-        9,
-        9,
         8,
-        29,
-        29,
-        35,
-        45,
-        48,
-        48,
-        44,
-        31,
-        31,
-        10,
-        10,
-        10,
-        26,
-        26,
-        18,
-        19,
-        29,
-        176,
-        176,
-        176,
-        9,
-        9,
-        9,
         8,
+        12,
+        10,
+        17,
+        9,
+        20,
+        18,
+        7,
         8,
         6,
         7,
+        5,
+        11,
+        15,
+        50,
+        14,
+        9,
+        13,
+        31,
+        6,
+        10,
+        22,
+        12,
+        14,
+        9,
+        11,
+        12,
+        24,
+        11,
+        22,
+        22,
+        28,
+        12,
+        40,
+        22,
+        13,
+        17,
+        13,
+        11,
+        5,
+        26,
+        17,
+        11,
+        9,
+        14,
+        20,
+        23,
+        19,
+        9,
+        6,
+        7,
+        23,
+        13,
+        11,
+        11,
+        17,
+        12,
         8,
-        8,
+        12,
+        11,
+        10,
+        13,
+        20,
+        7,
+        35,
+        36,
+        5,
+        24,
+        20,
+        28,
+        23,
+        10,
+        12,
+        20,
+        72,
+        13,
+        19,
+        16,
         8,
         18,
+        12,
+        13,
+        17,
+        7,
         18,
+        52,
+        17,
+        16,
+        15,
+        5,
+        23,
+        11,
+        13,
+        12,
+        9,
+        9,
+        5,
+        8,
+        28,
+        22,
+        35,
+        45,
+        48,
+        43,
+        13,
+        31,
+        7,
+        10,
+        10,
+        9,
+        8,
         18,
+        19,
+        2,
+        29,
+        176,
+        7,
+        8,
+        9,
+        4,
+        8,
+        5,
+        6,
+        5,
+        6,
+        8,
+        8,
+        3,
+        18,
+        3,
+        3,
         21,
         26,
-        26,
-        27,
+        9,
+        8,
         24,
-        24,
-        24,
-        14,
+        13,
+        10,
+        7,
         12,
         15,
         21,
-        21,
-        21,
-        20,
-        14,
+        10,
         20,
         14,
         9,
-        5,
+        6,
     ],
     Book.PROVERBS: [
         33,
@@ -668,8 +713,30 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         33,
         31,
     ],
-    Book.ECCLESIASTES: [18, 26, 22, 17, 20, 12, 30, 17, 18, 20, 10, 14],
-    Book.SONG_OF_SONGS: [17, 17, 11, 16, 17, 13, 13, 14],
+    Book.ECCLESIASTES: [
+        18,
+        26,
+        22,
+        16,
+        20,
+        12,
+        29,
+        17,
+        18,
+        20,
+        10,
+        14,
+    ],
+    Book.SONG_OF_SONGS: [
+        17,
+        17,
+        11,
+        16,
+        16,
+        13,
+        13,
+        14,
+    ],
     Book.ISAIAH: [
         31,
         22,
@@ -692,7 +759,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         6,
         17,
-        26,
+        25,
         18,
         23,
         12,
@@ -715,7 +782,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         28,
         28,
-        26,
+        25,
         13,
         15,
         22,
@@ -736,7 +803,6 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         19,
         12,
         25,
-        25,
         24,
     ],
     Book.JEREMIAH: [
@@ -760,7 +826,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         23,
         15,
         18,
-        15,
+        14,
         30,
         40,
         10,
@@ -770,7 +836,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         32,
         24,
-        42,
+        40,
         44,
         26,
         22,
@@ -793,7 +859,13 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         64,
         34,
     ],
-    Book.LAMENTATIONS: [22, 22, 66, 22, 22],
+    Book.LAMENTATIONS: [
+        22,
+        22,
+        66,
+        22,
+        22,
+    ],
     Book.EZEKIEL: [
         28,
         10,
@@ -837,26 +909,118 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         49,
         26,
         20,
-        28,
+        27,
         31,
         25,
         24,
         23,
         35,
     ],
-    Book.DANIEL: [21, 49, 100, 37, 31, 29, 28, 27, 27, 21, 45, 13, 65, 42],
-    Book.HOSEA: [11, 24, 5, 19, 15, 11, 16, 14, 17, 15, 12, 15, 16, 10],
-    Book.JOEL: [20, 32, 26],
-    Book.AMOS: [15, 16, 15, 13, 27, 15, 17, 14, 15],
-    Book.OBADIAH: [21],
-    Book.JONAH: [17, 11, 10, 11],
-    Book.MICAH: [16, 13, 12, 14, 15, 18, 20],
-    Book.NAHUM: [15, 14, 19],
-    Book.HABAKKUK: [17, 20, 19],
-    Book.ZEPHANIAH: [18, 15, 20],
-    Book.HAGGAI: [15, 24],
-    Book.ZECHARIAH: [21, 17, 10, 14, 11, 15, 14, 23, 17, 12, 17, 14, 9, 21],
-    Book.MALACHI: [14, 17, 18, 6],
+    Book.DANIEL: [
+        21,
+        49,
+        30,
+        37,
+        31,
+        28,
+        28,
+        27,
+        27,
+        21,
+        45,
+        13,
+    ],
+    Book.HOSEA: [
+        11,
+        23,
+        5,
+        19,
+        15,
+        11,
+        16,
+        14,
+        17,
+        15,
+        12,
+        14,
+        16,
+        9,
+    ],
+    Book.JOEL: [
+        20,
+        32,
+        21,
+    ],
+    Book.AMOS: [
+        15,
+        16,
+        15,
+        13,
+        27,
+        14,
+        17,
+        14,
+        15,
+    ],
+    Book.OBADIAH: [
+        21,
+    ],
+    Book.JONAH: [
+        17,
+        10,
+        10,
+        11,
+    ],
+    Book.MICAH: [
+        16,
+        13,
+        12,
+        13,
+        15,
+        16,
+        20,
+    ],
+    Book.NAHUM: [
+        15,
+        13,
+        19,
+    ],
+    Book.HABAKKUK: [
+        17,
+        20,
+        19,
+    ],
+    Book.ZEPHANIAH: [
+        18,
+        15,
+        20,
+    ],
+    Book.HAGGAI: [
+        15,
+        23,
+    ],
+    Book.ZECHARIAH: [
+        21,
+        13,
+        10,
+        14,
+        11,
+        15,
+        14,
+        23,
+        17,
+        12,
+        17,
+        14,
+        9,
+        21,
+    ],
+    Book.MALACHI: [
+        14,
+        17,
+        18,
+        6,
+    ],
     Book.MATTHEW: [
         25,
         23,
@@ -887,10 +1051,27 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         66,
         20,
     ],
-    Book.MARK: [45, 28, 35, 41, 43, 56, 37, 39, 50, 52, 33, 44, 37, 72, 47, 20],
+    Book.MARK: [
+        45,
+        28,
+        35,
+        41,
+        43,
+        56,
+        37,
+        38,
+        50,
+        52,
+        33,
+        44,
+        37,
+        72,
+        47,
+        20,
+    ],
     Book.LUKE: [
         80,
-        53,
+        52,
         38,
         44,
         39,
@@ -898,7 +1079,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         50,
         56,
         62,
-        43,
+        42,
         54,
         59,
         35,
@@ -915,12 +1096,12 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         53,
     ],
     Book.JOHN: [
-        52,
+        51,
         25,
         36,
         54,
         47,
-        72,
+        71,
         53,
         59,
         41,
@@ -967,7 +1148,24 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         44,
         31,
     ],
-    Book.ROMANS: [32, 29, 31, 25, 21, 23, 25, 39, 33, 21, 36, 21, 14, 26, 33, 27],
+    Book.ROMANS: [
+        32,
+        29,
+        31,
+        25,
+        21,
+        23,
+        25,
+        39,
+        33,
+        21,
+        36,
+        21,
+        14,
+        23,
+        33,
+        27,
+    ],
     Book.CORINTHIANS_1: [
         31,
         16,
@@ -986,25 +1184,133 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         58,
         24,
     ],
-    Book.CORINTHIANS_2: [24, 17, 18, 18, 21, 18, 16, 24, 15, 18, 33, 21, 14],
-    Book.GALATIANS: [24, 21, 29, 31, 26, 18],
-    Book.EPHESIANS: [23, 22, 21, 32, 33, 24],
-    Book.PHILIPPIANS: [30, 30, 21, 23],
-    Book.COLOSSIANS: [29, 23, 25, 18],
-    Book.THESSALONIANS_1: [10, 20, 13, 18, 28],
-    Book.THESSALONIANS_2: [12, 17, 18],
-    Book.TIMOTHY_1: [20, 15, 16, 16, 25, 21],
-    Book.TIMOTHY_2: [18, 26, 17, 22],
-    Book.TITUS: [16, 15, 15],
-    Book.PHILEMON: [25],
-    Book.HEBREWS: [14, 18, 19, 16, 14, 20, 28, 13, 28, 39, 40, 29, 25],
-    Book.JAMES: [27, 26, 18, 17, 20],
-    Book.PETER_1: [25, 25, 22, 19, 14],
-    Book.PETER_2: [21, 22, 18],
-    Book.JOHN_1: [10, 29, 24, 21, 21],
-    Book.JOHN_2: [13],
-    Book.JOHN_3: [15],
-    Book.JUDE: [25],
+    Book.CORINTHIANS_2: [
+        24,
+        17,
+        18,
+        18,
+        21,
+        18,
+        16,
+        24,
+        15,
+        18,
+        33,
+        21,
+        14,
+    ],
+    Book.GALATIANS: [
+        24,
+        21,
+        29,
+        31,
+        26,
+        18,
+    ],
+    Book.EPHESIANS: [
+        23,
+        22,
+        21,
+        32,
+        33,
+        24,
+    ],
+    Book.PHILIPPIANS: [
+        30,
+        30,
+        21,
+        23,
+    ],
+    Book.COLOSSIANS: [
+        29,
+        23,
+        25,
+        18,
+    ],
+    Book.THESSALONIANS_1: [
+        10,
+        20,
+        13,
+        18,
+        28,
+    ],
+    Book.THESSALONIANS_2: [
+        12,
+        17,
+        18,
+    ],
+    Book.TIMOTHY_1: [
+        20,
+        15,
+        16,
+        16,
+        25,
+        21,
+    ],
+    Book.TIMOTHY_2: [
+        18,
+        26,
+        17,
+        22,
+    ],
+    Book.TITUS: [
+        16,
+        15,
+        15,
+    ],
+    Book.PHILEMON: [
+        25,
+    ],
+    Book.HEBREWS: [
+        14,
+        18,
+        19,
+        16,
+        14,
+        20,
+        28,
+        13,
+        28,
+        39,
+        40,
+        29,
+        25,
+    ],
+    Book.JAMES: [
+        27,
+        26,
+        18,
+        17,
+        20,
+    ],
+    Book.PETER_1: [
+        25,
+        25,
+        22,
+        19,
+        14,
+    ],
+    Book.PETER_2: [
+        21,
+        22,
+        18,
+    ],
+    Book.JOHN_1: [
+        10,
+        29,
+        24,
+        21,
+        21,
+    ],
+    Book.JOHN_2: [
+        13,
+    ],
+    Book.JOHN_3: [
+        14,
+    ],
+    Book.JUDE: [
+        25,
+    ],
     Book.REVELATION: [
         20,
         29,
@@ -1017,8 +1323,8 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         21,
         11,
         19,
+        17,
         18,
-        19,
         20,
         8,
         21,
@@ -1166,36 +1472,55 @@ VERSE_IDS: tuple[int, ...] = __generate_verse_ids()
 
 
 @lru_cache()
-def get_number_of_chapters(book: Book) -> int:
+def get_number_of_chapters(book: Book, bible: Bible | None = None) -> int:
     """Return the number of chapters in a Book of the Bible.
 
     :param book: a book of the Bible
     :type book: Book
+    :param bible: an optional Bible object to check for chapter existence
+    :type bible: Bible | None
     :return: the number of chapters in the given book of the Bible
     :rtype: int
     """
+    if bible is not None:
+        return bible.get_number_of_chapters(book)
+
     return len(MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER[book])
 
 
 @lru_cache()
-def is_single_chapter_book(book: Book) -> bool:
-    return get_number_of_chapters(book) == 1
+def is_single_chapter_book(book: Book, bible: Bible | None = None) -> bool:
+    """Check if the given book is a single chapter book.
+
+    :param book: a book of the Bible
+    :type book: Book
+    :param bible: an optional Bible object to check for chapter existence
+    :type bible: Bible | None
+    :return: True if the given book is a single chapter book; otherwise, False
+    :rtype: bool
+    """
+    return get_number_of_chapters(book, bible) == 1
 
 
 @lru_cache()
-def get_number_of_verses(book: Book, chapter: int) -> int:
+def get_number_of_verses(book: Book, chapter: int, bible: Bible | None = None) -> int:
     """Return the number of verses in a Book and chapter.
 
     :param book: a book of the Bible
     :type book: Book
     :param chapter: a chapter of the given book of the Bible
     :type chapter: int
+    :param bible: an optional Bible object to check for verse existence
+    :type bible: Bible | None
     :return: the number of verses in the given book and chapter
     :rtype: int
     :raises InvalidChapterError: if the given chapter isn't a valid chapter for the
                                  given book
     """
-    chapter_list: list[int] = MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER[book]
+    if bible is not None:
+        return bible.get_number_of_verses(book, chapter)
+
+    chapter_list: list[int] = MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER.get(book, [])
 
     try:
         return chapter_list[chapter - 1]
@@ -1208,7 +1533,12 @@ def get_number_of_verses(book: Book, chapter: int) -> int:
 
 
 @lru_cache()
-def get_verse_id(book: Book, chapter: int, verse: int) -> int:
+def get_verse_id(
+    book: Book,
+    chapter: int,
+    verse: int,
+    bible: Bible | None = None,
+) -> int:
     """Return the verse id for the given Book, chapter number, and verse number.
 
     :param book: a book of the Bible
@@ -1217,12 +1547,14 @@ def get_verse_id(book: Book, chapter: int, verse: int) -> int:
     :type chapter: int
     :param verse: a verse number for the given book and chapter
     :type verse: int
+    :param bible: an optional Bible object to check for verse existence
+    :type bible: Bible | None
     :return: the verse id for the given book, chapter, and verse
     :rtype: int
     :raises InvalidVerseError: if the verse doesn't exist for the given book, chapter,
                                and verse
     """
-    max_verse_number: int | None = get_number_of_verses(book, chapter)
+    max_verse_number: int | None = get_number_of_verses(book, chapter, bible)
 
     if max_verse_number and not 1 <= verse <= max_verse_number:
         error_message = (
